@@ -3,6 +3,7 @@ from django.apps import apps
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
+from tecdoc.utils import get_supplier
 from manufacturers.signals import manufacturer_replaced
 
 
@@ -26,6 +27,8 @@ class Manufacturer(models.Model):
         null=True,
         upload_to='manufacturers')
 
+    supplier_id = models.IntegerField(blank=True, null=True)
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._original_new_name = self.new_name
@@ -34,7 +37,16 @@ class Manufacturer(models.Model):
         return self.name
 
     def save(self, **kwargs):
+        
+        try:
+            supplier = get_supplier(self.new_name or self.name)
+        except Exception:
+            supplier = None
+
+        self.supplier_id = supplier.id if supplier else None
+
         super().save(**kwargs)
+        
         if self.new_name == self._original_new_name:
             return
 
@@ -51,6 +63,12 @@ class Manufacturer(models.Model):
         def _handle_adjustment_async(manufacturer_id):
             _handle_adjustment(manufacturer_id)
 
+    def has_supplier(self):
+        return bool(self.supplier_id)
+
+    has_supplier.short_description = 'Tecdoc'
+    has_supplier.boolean = True
+
     class Meta:
         ordering = ['name']
         verbose_name = _('Manufacturer')
